Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Catppuccin = New( "catppuccin", []*Variant{ catppucinVariant(catppuccin.Latte), catppucinVariant(catppuccin.Frappe), catppucinVariant(catppuccin.Macchiato), catppucinVariant(catppuccin.Mocha), }, )
Catppuccin consists of 4 beautiful pastel color palettes, named flavors.
var Themes = []*Theme{ Catppuccin, }
Themes contains all available themes.
Functions ¶
This section is empty.
Types ¶
type Theme ¶
type Theme struct {
// Name is the name of the theme.
Name string
// Variants are the different styles that exists for a specific theme. These
// are the standard styles and themes might allow you to customise them
// further if you use them directly.
Variants []*Variant
}
Theme represents a theme and its variants.
type Variant ¶
type Variant struct {
// Name is the name of the flavour.
Name string
// Background is the background color of the flavour. This is only used while
// rendering the example asset for the flavour.
Background string
// Styles are the actual styles that are used to render the log lines.
Styles *log.Styles
}
Variant represents a single style within a theme.
Click to show internal directories.
Click to hide internal directories.